@@ -21,3 +21,13 @@ from siddon import *
 import simu
 import secchi
 import phantom
+import models
+
+try:
+    import lo
+except ImportError:
+    pass
+
+if 'lo' in locals():
+    from lo_wrapper import *
+
