@@ -2,8 +2,11 @@
 If lo package is present, define siddon lo wrapper
 """
 import lo
+import fitsarray as fa
+from siddon import dataarray_from_header, backprojector, projector
+from siddon import backprojector4d, projector4d
 
-def siddon_lo(data_header, cube_header):
+def siddon_lo(data_header, cube_header, obstacle=None):
     """
     A linear operator performing projection and backprojection using
     Siddon.
@@ -15,21 +18,19 @@ def siddon_lo(data_header, cube_header):
     def matvec(x):
         y = dataarray_from_header(data_header)
         y[:] = 0
-        projector(y, x)
+        projector(y, x, obstacle=obstacle)
         return y
     def rmatvec(x):
         y = fa.fitsarray_from_header(cube_header)
         y[:] = 0
-        backprojector(x, y)
+        backprojector(x, y, obstacle=obstacle)
         return y
-    return lo.ndsubclass(cube, data, matvec=matvec, rmatvec=rmatvec)
+    return lo.ndsubclass(cube, data, matvec=matvec, rmatvec=rmatvec, dtype=data.dtype)
 
-def siddon_sun_lo(data_header, cube_header):
+def siddon4d_lo(data_header, cube_header, obstacle=None):
     """
     A linear operator performing projection and backprojection using
-    Siddon.
-    Rays are blocked at a centered sphere of radius one (as it is the
-    case in solar tomography).
+    Siddon 4-dimensional variation.
     """
     data = dataarray_from_header(data_header)
     data[:] = 0
@@ -38,12 +39,11 @@ def siddon_sun_lo(data_header, cube_header):
     def matvec(x):
         y = dataarray_from_header(data_header)
         y[:] = 0
-        projector_sun(y, x)
+        projector4d(y, x, obstacle=obstacle)
         return y
     def rmatvec(x):
         y = fa.fitsarray_from_header(cube_header)
         y[:] = 0
-        backprojector_sun(x, y)
+        backprojector4d(x, y, obstacle=obstacle)
         return y
-    return lo.ndsubclass(cube, data, matvec=matvec, rmatvec=rmatvec)
-
+    return lo.ndsubclass(cube, data, matvec=matvec, rmatvec=rmatvec, dtype=data.dtype)
